@@ -106,7 +106,7 @@ def warnings(postcode='21037', country='de', lang='de'):
 
 try:
 	from gi.repository import AppIndicator3 as appindicator
-except
+except:
 	pass
 from gi.repository import Gtk as gtk
 from gi.repository import GLib
